@@ -5,7 +5,7 @@ CWD = Path.cwd()
 
 
 def copy_example(path: Path = CWD):
-    """Copy AutoHotkey scripts to the current directory."""
+    """Copy example configuration and AutoHotkey scripts to the current directory."""
     import gradedoc
 
     scripts = Path(gradedoc.__file__).parent / "example"
